@@ -58,7 +58,6 @@ def is_author(link, baseurl):
     else:
         return False
 
-
 def is_review(link):
     if link is not None:
         match = re.search('^https?:\/\/www\.?quora.com\/Reviews-of[a-zA-Z0-9-\-]*$', link)
@@ -85,9 +84,6 @@ def check_activity_type(entry):
     else:
         return ACTIVITY_ITEM_TYPES.UPVOTE
 
-def is_new_ui(soup):
-    return soup.find('div', attrs={'class': 'ProfileTabs'}) is not None
-
 ####################################################################
 # API
 ####################################################################
@@ -104,15 +100,16 @@ class Quora:
             m = re.findall('\d', str(item))
             element = ''.join(m)
             data_stats.append(element)
+        data_stats = map(try_cast, data_stats)
 
-        user_dict = {'answers'   : try_cast(data_stats[1]),
+        user_dict = {'answers'   : data_stats[1],
                      'blogs'     : err,
-                     'edits'     : try_cast(data_stats[5]),
-                     'followers' : try_cast(data_stats[3]),
-                     'following' : try_cast(data_stats[4]),
+                     'edits'     : data_stats[5],
+                     'followers' : data_stats[3],
+                     'following' : data_stats[4],
                      'name'      : name,
-                     'posts'     : try_cast(data_stats[2]),
-                     'questions' : try_cast(data_stats[0]),
+                     'posts'     : data_stats[2],
+                     'questions' : data_stats[0],
                      'topics'    : err,
                      'username'  : user }
         return user_dict
